Activated class final

It did what it was asked.

Inheritance

Constructors

Activated()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String?
Something worth showing the player, or null when there is nothing to say.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited