canSeePoint method

bool canSeePoint(
  1. Vector3 point
)

Whether there is a clear line from this actor's eye to point.

For an actor whose business is with something that is not the focus.

Implementation

bool canSeePoint(Vector3 point) => system.canSeePoint(actor, point);