canSeePoint method
Whether there is a clear line from this actor's eye to point.
For an actor whose business is with something that is not the focus.
Implementation
bool canSeePoint(Vector3 point) => system.canSeePoint(actor, point);
Whether there is a clear line from this actor's eye to point.
For an actor whose business is with something that is not the focus.
bool canSeePoint(Vector3 point) => system.canSeePoint(actor, point);