RoomDoor class final
An opening in one of a room's walls.
offset is along that wall from its middle. sill is where the opening starts, for a room whose floor is lower than its neighbour's; null is the room's own floor.
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited