levelKits top-level constant
The kits a document's recipes may name.
Three, all of which take a seed, and none of which knows a genre:
room— floor, ceiling and four walls with doors cut in them, and RoomKit's optionalclutterplaced by the seed;corridor— a straight passage, with the sameclutter;scatter—countcopies of an entity or a brush, placed by the seed on the floor of a box, no two closer thanspacing.
Implementation
const Map<String, LevelKit> levelKits = <String, LevelKit>{
'room': RoomKit.build,
'corridor': CorridorKit.build,
'scatter': ScatterKit.build,
};